==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/xtcalHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "ڊԂуR[hԂ̌vZ"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "L[ږXg"
#define KEYC "vZ̒PʂƂȂ鍀ږXg"

/*-s*/
#define SRTT "׊鍀ږXg"
#define SRTC "L[ږŎw肵Pʍs̒ŁAs̏Ԃ߂邽߂̍ږw肷"
#define SRTF "l,t"

/*-c*/
#define CALT "vZ"
#define CALC "gݍ݂̉Zq֐gݍ킹w肷"

/*-a*/
#define FNMT C_FNMT
#define FNMC C_FNMC

/*-q*/
#define SEQT C_SEQT
#define SEQC C_SEQC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "vZŎw肵vZȂB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtcal -c '$z*$' -a vz -i dat.xt -o rsl.xt\n\
xtcal -c 'round($z/$X,0.1)' -a Xz -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtsel,xtmkdata"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-2.0.1.tar.gz: musashi-core-2.0.1/help/ja-sjis/xtcalHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "ڊԂуR[hԂ̌vZ"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "L[ږXg"
#define KEYC "vZ̒PʂƂȂ鍀ږXg"

/*-s*/
#define SRTT "׊鍀ږXg"
#define SRTC "L[ږŎw肵Pʍs̒ŁAs̏Ԃ߂邽߂̍ږw肷"
#define SRTF "l,t"

/*-c*/
#define CALT "vZ"
#define CALC "gݍ݂̉Zq֐gݍ킹w肷"

/*-a*/
#define FNMT C_FNMT
#define FNMC C_FNMC

/*-q*/
#define SEQT C_SEQT
#define SEQC C_SEQC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "vZŎw肵vZȂB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtcal -c '$z*$' -a vz -i dat.xt -o rsl.xt\n\
xtcal -c 'round($z/$X,0.1)' -a Xz -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtsel,xtmkdata"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
